@@ -1,13 +1,14 @@
 use strict; use warnings;
 package Swim::Plugin::cpan;
-our $VERSION = '0.0.3';
+our $VERSION = '0.0.4';
 
 package Swim::Pod;
 
 sub block_func_cpan_head {
     my ($self, $args) = @_;
     my $meta = $self->meta;
-    my $head_name = $self->option->{'pod-upper-head'} ? 'NAME' : 'Name';
+    my $uc = $self->option->{'pod-upper-head'};
+    my $head_name = $uc ? 'NAME' : 'Name';
     (my $name = $meta->{name}) =~ s/-/::/g;
     my $out = <<"...";
 =head1 $head_name
@@ -31,14 +32,13 @@ $name - $meta->{abstract}
 sub block_func_cpan_tail {
     my ($self, $args) = @_;
     my $meta = $self->meta;
+    my $uc = $self->option->{'pod-upper-head'};
+    my $head_see = $uc ? 'SEE ALSO' : 'See Also';
+    my $head_copyright = $uc
+        ? 'COPYRIGHT AND LICENSE'
+        : 'Copyright and License';
+
     my $out = '';
-    my ($head_see, $head_author, $head_copyright) = map {
-        $self->option->{'pod-upper-head'} ? uc($_) : $_
-    } (
-        'See Also',
-        'Author',
-        'Copyright and License',
-    );
     if (my $see = $meta->{see}) {
         $out .= "=head1 $head_see\n\n=over\n\n";
         $see = [$see] unless ref $see;
@@ -47,11 +47,8 @@ sub block_func_cpan_tail {
         }
         $out .= "=back\n\n";
     }
+    $out .= $self->_add_author_section;
     return $out . <<"...";
-=head1 $head_author
-
-$meta->{author}{name} <$meta->{author}{email}>
-
 =head1 $head_copyright
 
 Copyright $meta->{copyright}. $meta->{author}{name}.
@@ -63,4 +60,21 @@ See L<http://www.perl.com/perl/misc/Artistic.html>
 ...
 }
 
+sub _add_author_section {
+    my ($self) = @_;
+    my $meta = $self->meta;
+    my $uc = $self->option->{'pod-upper-head'};
+    my $head_author = $uc ? 'AUTHOR' : 'Author';
+    my @authors = ($meta->{author});
+    if (my $authors = $meta->{authors}) {
+        $head_author = $uc ? 'AUTHORS' : 'Authors';
+        push @authors, @$authors;
+    }
+    my $out = "=head1 $head_author\n\n";
+    for my $author (@authors) {
+        $out .= "$author->{name} <$author->{email}>\n\n";
+    }
+    return $out;
+}
+
 1;
